diff --git a/LCS/ACC/APS/include/APS/ParameterSet.h b/LCS/ACC/APS/include/APS/ParameterSet.h
index f72a077e0b804b8b57316655434c9a47359885b3..5760244fbe82561b7f091408b7d1812e8249ae6d 100644
--- a/LCS/ACC/APS/include/APS/ParameterSet.h
+++ b/LCS/ACC/APS/include/APS/ParameterSet.h
@@ -156,8 +156,9 @@ public:
 	// Checks if the given Key is defined in the ParameterSet.
 	bool	isDefined (const string& searchKey) const;
 
-	// Searches for a key whose name end in the given shortKey.
-	string	locateKey(const string&	shortKey) const;
+	// Searches for a module whose short nam is given and returns it position
+	// in the parameterSet.
+	string	locateModule(const string&	shortName) const;
 
 	// Returns the value as a boolean.
 	bool	getBool  (const string& aKey) const;
@@ -299,9 +300,9 @@ inline bool	ParameterSet::isDefined (const string& searchKey) const
 	return itsSet->isDefined (searchKey);
 }
 
-inline string	ParameterSet::locateKey(const string&	shortKey) const
+inline string	ParameterSet::locateModule(const string&	shortName) const
 {
-	return (itsSet->locateKey(shortKey));
+	return (itsSet->locateModule(shortName));
 }
 
 //#	getBool(key)
diff --git a/LCS/ACC/APS/src/ParameterSetImpl.cc b/LCS/ACC/APS/src/ParameterSetImpl.cc
index 53eb8ff292882d4fea844ba825fe4389d1492b93..839c99d0499d6012ecc810d9a9df54d5d7d3d089 100644
--- a/LCS/ACC/APS/src/ParameterSetImpl.cc
+++ b/LCS/ACC/APS/src/ParameterSetImpl.cc
@@ -885,11 +885,11 @@ int32 	indexValue (const string&	label, char	indexMarker[2])
 }
 
 //
-// locateKey(hortKey)
+// locateModule(shortKey)
 //
 // Searches for a key ending in the given 'shortkey' and returns it full name.
 // e.g: a.b.c.d.param=xxxx --> locateKey(d)-->a.b.c.
-string	ParameterSetImpl::locateKey(const string&	shortKey) const
+string	ParameterSetImpl::locateModule(const string&	shortKey) const
 {
 	const_iterator		iter = begin();
 	const_iterator		eom  = end();
diff --git a/LCS/ACC/APS/include/APS/ParameterSetImpl.h b/LCS/ACC/APS/include/APS/ParameterSetImpl.h
index 1e74314ba1582c9c98e06c272303ef3ec95e5cb8..069c55e2e905eb1ed3fa82307fc1bb2c8ce7b331 100644
--- a/LCS/ACC/APS/include/APS/ParameterSetImpl.h
+++ b/LCS/ACC/APS/include/APS/ParameterSetImpl.h
@@ -160,9 +160,9 @@ public:
 	bool	isDefined (const string& searchKey) const
 				{ return (find(searchKey) != end()); };
 
-	// Searches for a key whose name end in the given shortKey.
-	// e.g: a.b.c.d.param=xxx ; locateKey('d') --> 'a.b.c.'
-	string	locateKey(const string&	shortKey) const;
+	// Searches for a module whose name end in the given modulename.
+	// e.g: a.b.c.d.param=xxx ; locateModule('d') --> 'a.b.c.'
+	string	locateModule(const string&	shortName) const;
 
 	// Return the 'metadata' from the parameterCollection.
 //	string  getName          () const;